@@ -1,6 +1,7 @@
 /* ttylog - serial port logger
  Copyright (C) 1999-2002  Tibor Koleszar <oldw@debian.org>
- Copyright (C) 2008-2017  Robert James Clay <jame@rocasa.us>
+ Copyright (C) 2008-2018  Robert James Clay <jame@rocasa.us>
+ Copyright (C) 2017-2018  Guy Shapiro <guy.shapiro@mobi-wize.com>
  Copyright (C)      2016  Donald Gordon <donald@tawherotech.nz>
  Copyright (C)      2016  Alexander (MrMontag) Fust <MrMontagOpenDev@gmail.com>
  Copyright (C)      2016  Logan Rosen <loganrosen@gmail.com>
@@ -49,7 +50,8 @@ main (int argc, char *argv[])
 {
   FILE *logfile;
   fd_set rfds;
-  int retval, i, j, baud, stamp = -1;
+  int retval, i, j, baud = -1;
+  int stamp = 0;
   timer_t timerid;
   struct sigevent sevp;
   sevp.sigev_notify = SIGEV_SIGNAL;
@@ -75,7 +77,7 @@ main (int argc, char *argv[])
       if (!strcmp (argv[i], "-h") || !strcmp (argv[i], "--help"))
         {
           printf ("ttylog version %s\n", TTYLOG_VERSION);
-          printf ("Usage:  ttylog [-b|--baud] [-d|--device] [-f|--flush] [-t|--timeout] > /path/to/logfile\n");
+          printf ("Usage:  ttylog [-b|--baud] [-d|--device] [-f|--flush] [-s|--stamp] [-t|--timeout] > /path/to/logfile\n");
           printf (" -h, --help	This help\n -v, --version	Version number\n -b, --baud	Baud rate\n");
           printf (" -d, --device	Serial device (eg. /dev/ttyS1)\n -f, --flush	Flush output\n");
           printf (" -s, --stamp\tPrefix each line with datestamp\n");
@@ -87,7 +89,9 @@ main (int argc, char *argv[])
       if (!strcmp (argv[i], "-v") || !strcmp (argv[i], "--version"))
         {
           printf ("ttylog version %s\n", TTYLOG_VERSION);
-          printf ("Copyright (C) 2016 Robert James Clay <jame@rocasa.us>\n");
+          printf ("Copyright (C) 2018 Robert James Clay <jame@rocasa.us>\n");
+          printf ("Copyright (C) 2018 Guy Shapiro <guy.shapiro@mobi-wize.com>\n");
+          printf ("Copyright (C) 2016 Donald Gordon <donald@tawherotech.nz>\n");
           printf ("Copyright (C) 2016 Logan Rosen <loganrosen@gmail.com>\n");
           printf ("Copyright (C) 2016 Alexander (MrMontag) Fust <alexander.fust.info@gmail.com>\n");
           printf ("Copyright (C) 2002 Tibor Koleszar <oldw@debian.org>\n");
@@ -209,9 +213,12 @@ main (int argc, char *argv[])
       FD_ZERO (&rfds);
       FD_SET (fd, &rfds);
       retval = select (fd + 1, &rfds, NULL, NULL, NULL);
-      if (retval)
+      if (retval > 0)
         {
-          fgets (line, 1024, logfile);
+          if (!fgets (line, 1024, logfile))
+            {
+              if (ferror (logfile)) { break; }
+            }
           if (stamp)
             {
               time(&rawtime);
@@ -225,6 +232,7 @@ main (int argc, char *argv[])
 
           if (flush) { fflush(stdout); }
         }
+      else if (retval < 0) { break; }
     }
 
   fclose (logfile);
